.. webapi-error::
   :instance: djblets.webapi.errors.NOT_LOGGED_IN

   The resource requires that your client is logged in, and you're not logged
   in yet. This is sent along with ``WWW-Authenticate`` HTTP headers.

   See :ref:`2.0-authenticating` for more information.
